# square_authentication_helper

## about

helper to access the authentication layer for my personal server.

## installation

```shell
pip install square_authentication_helper
```

## usage

[reference python file](./example.py)

## env

- python>=3.12.0

## changelog

### v1.0.0

- initial implementation.

## Feedback is appreciated. Thank you!
